package com.app.ready.paykundemo
import android.app.Activity
import android.text.TextUtils
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import com.paykun.sdk.PaykunApiCall
import com.paykun.sdk.eventbus.Events
import com.paykun.sdk.eventbus.GlobalBus
import com.paykun.sdk.helper.PaykunHelper
import com.paykun.sdk.logonsquare.Transaction
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode
import org.json.JSONException
import org.json.JSONObject

class PayKunPayment {
    lateinit var activity: AppCompatActivity
    var paymentCallBack: ((errorMessage: String?, purchaseID: String?, transition: Transaction) -> Unit)? =
            null
    fun startPayKunPayment(
            activityObj: AppCompatActivity,
            merchantId: String,
            accessToken: String,
            customerName: String,
            customerEmail: String?,
            customerPhone: String?,
            productName: String,
            amount: String?,
            currency: String?,
            isLive: Boolean,
            callbackPayment: (errorMessage: String?, transitionID: String?, transition: Transaction) -> Unit
    ) {
        print("==>> startPayKunWith")
        GlobalBus.getBus().register(this)
        activity = activityObj;
        paymentCallBack = callbackPayment
        val obj = JSONObject()
        try {
            obj.put("merchant_id", merchantId)
            obj.put("access_token", accessToken)
            obj.put("customer_name", customerName)
            obj.put("customer_email", customerEmail)
            obj.put("customer_phone", customerPhone)
            obj.put("product_name", productName)
            obj.put("currency", currency)
            obj.put(
                    "order_no",
                    System.currentTimeMillis()
            ) // order no. should have 10 to 30 character in numeric format
            obj.put("amount", amount) // minimum amount should be 10
            obj.put("isLive", isLive) // need to send false if you are in sandbox mode
        } catch (e: JSONException) {
            e.printStackTrace()
        }
        PaykunApiCall.Builder(activity)
                .sendJsonObject(obj) // Paykun api to initialize your payment and send info.
    }

    @Subscribe(sticky = true, threadMode = ThreadMode.MAIN)
    fun getResults(message: Events.PaymentMessage) {
        try {
            if (message.transactionDetail == null)
                return
            val transactionDetail: Transaction = message.transactionDetail
            if (message.results.equals(PaykunHelper.MESSAGE_SUCCESS, ignoreCase = true)) {
                if (!TextUtils.isEmpty(message.transactionId)) {
                    Log.v(
                            " order id ",
                            " getting order id value : " + message.transactionDetail.order.orderId
                    )
                    paymentCallBack!!(null, message.transactionId, transactionDetail)
                }
            } else if (message.results.equals(PaykunHelper.MESSAGE_FAILED, ignoreCase = true)) {
                paymentCallBack!!.invoke("Your Transaction is failed", null, transactionDetail)
            } else if (message.results.equals(PaykunHelper.MESSAGE_SERVER_ISSUE, ignoreCase = true)
            ) {
                // do your stuff here
                paymentCallBack!!.invoke(PaykunHelper.MESSAGE_SERVER_ISSUE, null, transactionDetail)
            } else if (message.results.equals(
                            PaykunHelper.MESSAGE_ACCESS_TOKEN_MISSING, ignoreCase = true
                    )
            ) {
                paymentCallBack!!.invoke("Access Token missing", null, transactionDetail)
            } else if (message.results.equals(
                            PaykunHelper.MESSAGE_MERCHANT_ID_MISSING,
                            ignoreCase = true
                    )
            ) {
                paymentCallBack!!.invoke("Merchant Id is missing", null, transactionDetail)
            } else if (message.results.equals(
                            PaykunHelper.MESSAGE_INVALID_REQUEST,
                            ignoreCase = true
                    )
            ) {
                paymentCallBack!!.invoke("Invalid Request", null, transactionDetail)
            } else if (message.results.equals(
                            PaykunHelper.MESSAGE_NETWORK_NOT_AVAILABLE,
                            ignoreCase = true
                    )
            ) {
                paymentCallBack!!.invoke("Network is not available", null, transactionDetail)
            } else {
                paymentCallBack!!.invoke(
                        "Payment failed with unknown reason. Please try again latere",
                        null, transactionDetail
                )
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}
